==> ejc-riskmortgage-impl-3.0.0-20231129.014354-92-sources.jar: com/ejianc/business/approve/controller/ApproveController.java <==
package com.ejianc.business.approve.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.approve.bean.ApproveCashEntity;
import com.ejianc.business.approve.bean.ApproveCollectEntity;
import com.ejianc.business.cash.bean.CashEntity;
import com.ejianc.business.cash.service.ICashService;
import com.ejianc.business.collect.bean.CollectEntity;
import com.ejianc.business.collect.service.ICollectService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.approve.bean.ApproveEntity;
import com.ejianc.business.approve.service.IApproveService;
import com.ejianc.business.approve.vo.ApproveVO;

/**
 * 考核兑现审批表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("approve")
public class ApproveController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "APPROVE_CODE";//此处需要根据实际修改

    @Autowired
    private IApproveService service;

    @Autowired
    private ICashService cashService;

    @Autowired
    private ICollectService collectService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ApproveVO> saveOrUpdate(@RequestBody ApproveVO saveOrUpdateVO) {
    	ApproveEntity entity = BeanMapper.map(saveOrUpdateVO, ApproveEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);

    	//处理上游单据 引用状态
        if(CollectionUtils.isNotEmpty(entity.getApproveCashList())){
            List<Long> cashIds = entity.getApproveCashList().stream().map(ApproveCashEntity::getCashId).collect(Collectors.toList());
            LambdaUpdateWrapper<CashEntity> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper.in(CashEntity::getId, cashIds);
            updateWrapper.set(CashEntity::getApproveFlag, 1);
            cashService.update(updateWrapper);
        }

        if(CollectionUtils.isNotEmpty(entity.getApproveCollectList())){
            List<Long> collectIds = entity.getApproveCollectList().stream().map(ApproveCollectEntity::getCollectId).collect(Collectors.toList());
            LambdaUpdateWrapper<CollectEntity> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper.in(CollectEntity::getId, collectIds);
            updateWrapper.set(CollectEntity::getApproveFlag, 1);
            collectService.update(updateWrapper);
        }

    	ApproveVO vo = BeanMapper.map(entity, ApproveVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ApproveVO> queryDetail(Long id) {
    	ApproveEntity entity = service.selectById(id);
    	ApproveVO vo = BeanMapper.map(entity, ApproveVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ApproveVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            // 释放引用单据
            for (ApproveVO vo : vos) {
                ApproveEntity entity = service.selectById(vo.getId());
                if(CollectionUtils.isNotEmpty(entity.getApproveCashList())){
                    List<Long> cashIds = entity.getApproveCashList().stream().map(ApproveCashEntity::getCashId).collect(Collectors.toList());
                    LambdaUpdateWrapper<CashEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.in(CashEntity::getId, cashIds);
                    updateWrapper.set(CashEntity::getApproveFlag, 0);
                    cashService.update(updateWrapper);
                }

                if(CollectionUtils.isNotEmpty(entity.getApproveCollectList())){
                    List<Long> collectIds = entity.getApproveCollectList().stream().map(ApproveCollectEntity::getCollectId).collect(Collectors.toList());
                    LambdaUpdateWrapper<CollectEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.in(CollectEntity::getId, collectIds);
                    updateWrapper.set(CollectEntity::getApproveFlag, 0);
                    collectService.update(updateWrapper);
                }
            }
        }
        service.removeByIds(vos.stream().map(ApproveVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ApproveVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ApproveEntity> page = service.queryPage(param,false);
        IPage<ApproveVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ApproveVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ApproveEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Approve-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refApproveData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ApproveVO>> refApproveData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ApproveEntity> page = service.queryPage(param,false);
        IPage<ApproveVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ApproveVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-riskmortgage-impl-3.0.0-20231205.095049-100-sources.jar: com/ejianc/business/approve/controller/ApproveController.java <==
package com.ejianc.business.approve.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.approve.bean.ApproveCashEntity;
import com.ejianc.business.approve.bean.ApproveCollectEntity;
import com.ejianc.business.cash.bean.CashEntity;
import com.ejianc.business.cash.service.ICashService;
import com.ejianc.business.cash.vo.CashCostVO;
import com.ejianc.business.collect.bean.CollectEntity;
import com.ejianc.business.collect.service.ICollectService;
import com.ejianc.business.standard.bean.StandardEntity;
import com.ejianc.business.standard.service.IStandardService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.approve.bean.ApproveEntity;
import com.ejianc.business.approve.service.IApproveService;
import com.ejianc.business.approve.vo.ApproveVO;

/**
 * 考核兑现审批表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("approve")
public class ApproveController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "APPROVE_CODE";//此处需要根据实际修改

    @Autowired
    private IApproveService service;

    @Autowired
    private ICashService cashService;

    @Autowired
    private ICollectService collectService;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IStandardService standardService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ApproveVO> saveOrUpdate(@RequestBody ApproveVO saveOrUpdateVO) {
    	ApproveEntity entity = BeanMapper.map(saveOrUpdateVO, ApproveEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);

    	//处理上游单据 引用状态
        if(CollectionUtils.isNotEmpty(entity.getApproveCashList())){
            List<Long> cashIds = entity.getApproveCashList().stream().map(ApproveCashEntity::getCashId).collect(Collectors.toList());
            LambdaUpdateWrapper<CashEntity> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper.in(CashEntity::getId, cashIds);
            updateWrapper.set(CashEntity::getApproveFlag, 1);
            cashService.update(updateWrapper);
        }

        if(CollectionUtils.isNotEmpty(entity.getApproveCollectList())){
            List<Long> collectIds = entity.getApproveCollectList().stream().map(ApproveCollectEntity::getCollectId).collect(Collectors.toList());
            LambdaUpdateWrapper<CollectEntity> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper.in(CollectEntity::getId, collectIds);
            updateWrapper.set(CollectEntity::getApproveFlag, 1);
            collectService.update(updateWrapper);
        }

    	ApproveVO vo = BeanMapper.map(entity, ApproveVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ApproveVO> queryDetail(Long id) {
    	ApproveEntity entity = service.selectById(id);
    	ApproveVO vo = BeanMapper.map(entity, ApproveVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description queryCostMny 根据项目获取实际成本金额 / 校验是否有风险抵押金标准数据
     * @param projectId
     */
    @RequestMapping(value = "/queryCostMny", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CashCostVO> queryCostMny(Long projectId) {
        CashCostVO resVo = new CashCostVO();
        List<Integer> billList = new ArrayList<>();
        billList.add(BillStateEnum.PASSED_STATE.getBillStateCode());
        billList.add(BillStateEnum.COMMITED_STATE.getBillStateCode());
        LambdaQueryWrapper<StandardEntity> lambda = Wrappers.<StandardEntity>lambdaQuery();
        lambda.eq(StandardEntity::getRiskDepositType, "projectDept");
        lambda.eq(StandardEntity::getProjectId, projectId);
        lambda.in(StandardEntity::getBillState,billList);
        List<StandardEntity> resList = standardService.list(lambda);
        if(CollectionUtils.isNotEmpty(resList)){
            resVo.setType(0);
            resVo.setRiskDepositMny(resList.get(0).getRiskDepositMny());
        }else{
            resVo.setType(1);
        }
        return CommonResponse.success("查询详情数据成功！",resVo);
    }
    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ApproveVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            // 释放引用单据
            for (ApproveVO vo : vos) {
                ApproveEntity entity = service.selectById(vo.getId());
                if(CollectionUtils.isNotEmpty(entity.getApproveCashList())){
                    List<Long> cashIds = entity.getApproveCashList().stream().map(ApproveCashEntity::getCashId).collect(Collectors.toList());
                    LambdaUpdateWrapper<CashEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.in(CashEntity::getId, cashIds);
                    updateWrapper.set(CashEntity::getApproveFlag, 0);
                    cashService.update(updateWrapper);
                }

                if(CollectionUtils.isNotEmpty(entity.getApproveCollectList())){
                    List<Long> collectIds = entity.getApproveCollectList().stream().map(ApproveCollectEntity::getCollectId).collect(Collectors.toList());
                    LambdaUpdateWrapper<CollectEntity> updateWrapper = new LambdaUpdateWrapper<>();
                    updateWrapper.in(CollectEntity::getId, collectIds);
                    updateWrapper.set(CollectEntity::getApproveFlag, 0);
                    collectService.update(updateWrapper);
                }
            }
        }
        service.removeByIds(vos.stream().map(ApproveVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ApproveVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ApproveEntity> page = service.queryPage(param,false);
        IPage<ApproveVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ApproveVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ApproveEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Approve-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refApproveData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ApproveVO>> refApproveData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ApproveEntity> page = service.queryPage(param,false);
        IPage<ApproveVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ApproveVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
